==> mongodb_5.3.1.orig.tar.gz: mongo-r5.3.1/src/mongo/db/s/sharding_data_transform_metrics_observer.cpp <==
/**
 *    Copyright (C) 2022-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#include "mongo/db/s/sharding_data_transform_metrics_observer.h"
#include "mongo/util/assert_util.h"

namespace mongo {

ShardingDataTransformMetricsObserver::ShardingDataTransformMetricsObserver(
    ShardingDataTransformInstanceMetrics* metrics)
    : _metrics(metrics) {}

int64_t ShardingDataTransformMetricsObserver::getRemainingTimeMillis() const {
    MONGO_UNREACHABLE;
}

int64_t ShardingDataTransformMetricsObserver::getStartTimestamp() const {
    MONGO_UNREACHABLE;
}

const UUID& ShardingDataTransformMetricsObserver::getUuid() const {
    MONGO_UNREACHABLE;
}

}  // namespace mongo

==> mongodb_6.1.1.orig.tar.gz: mongo-r6.1.1/src/mongo/db/s/sharding_data_transform_metrics_observer.cpp <==
/**
 *    Copyright (C) 2022-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#include "mongo/db/s/sharding_data_transform_metrics_observer.h"

namespace mongo {

ShardingDataTransformMetricsObserver::ShardingDataTransformMetricsObserver(
    ShardingDataTransformInstanceMetrics* metrics)
    : _metrics(metrics) {}

boost::optional<Milliseconds>
ShardingDataTransformMetricsObserver::getHighEstimateRemainingTimeMillis() const {
    return _metrics->getHighEstimateRemainingTimeMillis();
}

boost::optional<Milliseconds>
ShardingDataTransformMetricsObserver::getLowEstimateRemainingTimeMillis() const {
    return _metrics->getLowEstimateRemainingTimeMillis();
}

Date_t ShardingDataTransformMetricsObserver::getStartTimestamp() const {
    return _metrics->getStartTimestamp();
}

const UUID& ShardingDataTransformMetricsObserver::getUuid() const {
    return _metrics->getInstanceId();
}

ShardingDataTransformMetrics::Role ShardingDataTransformMetricsObserver::getRole() const {
    return _metrics->getRole();
}

}  // namespace mongo
